@@ -16,15 +16,15 @@ Ixchel::Actions::sagan_rules - Generate the rules include for Sagan.
 
 =head1 VERSION
 
-Version 0.3.0
+Version 0.4.0
 
 =cut
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.4.0';
 
 =head1 CLI SYNOPSIS
 
-ixchel -a sagan_rules [B<--np>] [B<-w>] [B<-i> <instance>]
+ixchel -a sagan_rules [B<-w>] [B<-i> <instance>]
 
 =head1 CODE SYNOPSIS
 
@@ -36,11 +36,6 @@ ixchel -a sagan_rules [B<--np>] [B<-w>] [B<-i> <instance>]
 
 =head1 DESCRIPTION
 
-Generates the rules include for sagan using the array .sagan.rules and
-if .sagan.instances_rules.$instance exists, that will be merged into it.
-
-The resulting array is deduplicated using L<List::Util>->uniq.
-
 Any item that does not match /\// or /\$/ has '$RULE_PATH/' prepended to it.
 
 If told to write it out, .sagan.config_base is used as the base directory to write
@@ -57,10 +52,6 @@ Write out the generated rule files.
 
 A instance to operate on.
 
-=head2 --no_die_at_end
-
-Don't die if there are errors encounted at the end.
-
 =head1 RESULT HASH REF
 
     .errors :: A array of errors encountered.
@@ -74,7 +65,7 @@ sub new_extra { }
 sub action_extra {
 	my $self = $_[0];
 
-	my $url = 'https://raw.githubusercontent.com/quadrantsec/sagan-rules/main/rules.yaml';
+	my $url = $self->{config}{sagan}{rules};
 
 	my $base_config_raw;
 	eval {
@@ -216,7 +207,7 @@ sub process_file {
 				$custom_rules->{$rule} = 1;
 			}
 		}
-		my $custom_rules_array = keys( %{$custom_rules} );
+		my @custom_rules_array = keys( %{$custom_rules} );
 
 		# begin putting it back together
 		$filled_in = '';
@@ -254,6 +245,13 @@ sub process_file {
 			} ## end else [ if ($ignore_line) ]
 		} ## end foreach my $line ( @{ $self->{base_config_split...}})
 
+		if ( defined( $custom_rules_array[0] ) ) {
+			$filled_in = $filled_in = "\n\n\n  # rules found in the file but not in the source rules.yaml file\n";
+			foreach my $custom_rule (@custom_rules_array) {
+				$filled_in = $filled_in . '  - ' . $custom_rule . "\n";
+			}
+		}
+
 		$self->status_add(
 			status => '-----[ ' . $file . ' ]-------------------------------------' . "\n" . $filled_in );
 
